#!/bin/sh
# $Id: solaris8.sh,v 1.6 2001/05/28 13:05:46 acormier Exp $

if [ -z $TSP_VERBOSE ]; then
   TSP_VERBOSE=0
fi

function Display
{
   if [ -z $TSP_VERBOSE ]; then
      return;
   fi
   if [ $TSP_VERBOSE -lt $1 ]; then
      return;
   fi
   shift
   echo $*
}

function Exec
{
   if [ ! -z $TSP_VERBOSE ]; then
      if [ $TSP_VERBOSE -ge 2 ]; then
         echo $*
      fi
   fi
   $* # Execute command
   if [ $? -ne 0 ]; then
      echo "Error while executing $1"
      echo "   Command: $*"
      exit 1
   fi
}

# Program localization 

Display 1 "--- Start of configuration script. ---"
Display 1 "Script: " `basename $0`

ifconfig=/sbin/ifconfig
route=/sbin/route
inetinit=/etc/init.d/inetinit

if [ -z $TSP_HOME_DIR ]; then
   echo "TSP_HOME_DIR variable not specified!;"
   exit 1
fi

if [ ! -d $TSP_HOME_DIR ]; then
   echo "Error : directory $TSP_HOME_DIR does not exist"
   exit 1
fi
#

if [ -z $TSP_HOST_TYPE ]; then
   echo Error: TSP_HOST_TYPE not defined.
   exit 1
fi

#change to upper case
TSP_HOST_TYPE=`echo $TSP_HOST_TYPE | tr a-z A-Z`

if [ X"${TSP_HOST_TYPE}" = X"HOST" ] || [ X"${TSP_HOST_TYPE}" = X"ROUTER" ]; then
   #
   # Configured tunnel config (IPv6) 
   Display 1 Setting up interface $TSP_TUNNEL_INTERFACE
   Exec $ifconfig $TSP_TUNNEL_INTERFACE inet6 plumb 
   Exec $ifconfig $TSP_TUNNEL_INTERFACE inet6 tsrc $TSP_CLIENT_ADDRESS_IPV4 tdst $TSP_SERVER_ADDRESS_IPV4 up
   Exec $ifconfig $TSP_TUNNEL_INTERFACE inet6 addif $TSP_CLIENT_ADDRESS_IPV6 $TSP_SERVER_ADDRESS_IPV6 up 

   # Default route  
   $route del -inet6 default $TSP_IPV6_TUNNEL_SERVER 2>/dev/null
   Exec $route add -inet6 default $TSP_IPV6_TUNNEL_SERVER 
   Exec $inetinit start
fi

Display 1 "--- End of configuration script. ---"

exit 0
